@@ -12,7 +12,7 @@ from .common.throttle.ThrottleStep import ThrottleStep
 class LiveBreakpoint(LiveInstrument):
     def __init__(self, location: LiveSourceLocation):
         super().__init__(location)
-        self.hitLimit = 1
+        self.hit_limit = 1
         self.type = LiveInstrumentType.BREAKPOINT
 
     @classmethod
